summaryrefslogtreecommitdiffstats
path: root/generic/tclStringRep.h
diff options
context:
space:
mode:
authorjan.nijtmans <nijtmans@users.sourceforge.net>2022-10-25 13:22:46 (GMT)
committerjan.nijtmans <nijtmans@users.sourceforge.net>2022-10-25 13:22:46 (GMT)
commit3bbc297ec7cefc93fa96031c1d149c79734c4555 (patch)
tree524add222ec6eec44a35d9dc9095390fa17b7752 /generic/tclStringRep.h
parent415503775a3b650db8252a333b5f3c21b02d3c24 (diff)
parentd33fc57550e1921bfadb8fe4b90d7e55bf23e6f5 (diff)
downloadtcl-3bbc297ec7cefc93fa96031c1d149c79734c4555.zip
tcl-3bbc297ec7cefc93fa96031c1d149c79734c4555.tar.gz
tcl-3bbc297ec7cefc93fa96031c1d149c79734c4555.tar.bz2
Merge 8.7
Diffstat (limited to 'generic/tclStringRep.h')
-rw-r--r--generic/tclStringRep.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/generic/tclStringRep.h b/generic/tclStringRep.h
index 425f08c..ab52ea8 100644
--- a/generic/tclStringRep.h
+++ b/generic/tclStringRep.h
@@ -51,15 +51,15 @@
*/
typedef struct {
- size_t numChars; /* The number of chars in the string. -1 means
- * this value has not been calculated. Any other
- * means that there is a valid Unicode rep, or
- * that the number of UTF bytes == the number
- * of chars. */
- size_t allocated; /* The amount of space actually allocated for
+ Tcl_Size numChars; /* The number of chars in the string.
+ * TCL_INDEX_NONE means this value has not been
+ * calculated. Any other means that there is a valid
+ * Unicode rep, or that the number of UTF bytes ==
+ * the number of chars. */
+ Tcl_Size allocated; /* The amount of space actually allocated for
* the UTF string (minus 1 byte for the
* termination char). */
- size_t maxChars; /* Max number of chars that can fit in the
+ Tcl_Size maxChars; /* Max number of chars that can fit in the
* space allocated for the unicode array. */
int hasUnicode; /* Boolean determining whether the string has
* a Unicode representation. */